@@ -15,24 +15,48 @@ import cmd2
 # Help text for base cmd2.Cmd application
 BASE_HELP = """Documented commands (type help <topic>):
 ========================================
-_relative_load  edit  history  py        quit  save  shell      show
-cmdenvironment  help  load     pyscript  run   set   shortcuts
+alias  help     load  pyscript  set    shortcuts
+edit   history  py    quit      shell  unalias
+"""
+
+BASE_HELP_VERBOSE = """
+Documented commands (type help <topic>):
+================================================================================
+alias               Define or display aliases
+edit                Edit a file in a text editor.
+help                List available commands with "help" or detailed help with "help cmd".
+history             View, run, edit, and save previously entered commands.
+load                Runs commands in script file that is encoded as either ASCII or UTF-8 text.
+py                  Invoke python command, shell, or script
+pyscript            Runs a python script file inside the console
+quit                Exits this application.
+set                 Sets a settable parameter or shows current settings of parameters.
+shell               Execute a command as if at the OS prompt.
+shortcuts           Lists shortcuts (aliases) available.
+unalias             Unsets aliases
 """
 
 # Help text for the history command
-HELP_HISTORY = """history [arg]: lists past commands issued
+HELP_HISTORY = """usage: history [-h] [-r | -e | -s | -o FILE | -t TRANSCRIPT] [arg]
 
-        | no arg:         list all
-        | arg is integer: list one history item, by index
-        | a..b, a:b, a:, ..b -> list history items by a span of indices (inclusive)
-        | arg is string:  list all commands matching string search
-        | arg is /enclosed in forward-slashes/: regular expression search
+View, run, edit, and save previously entered commands.
 
-Usage: history [options] (limit on which commands to include)
+positional arguments:
+  arg                   empty               all history items
+                        a                   one history item by number
+                        a..b, a:b, a:, ..b  items by indices (inclusive)
+                        [string]            items containing string
+                        /regex/             items matching regular expression
 
-Options:
-  -h, --help    show this help message and exit
-  -s, --script  Script format; no separation lines
+optional arguments:
+  -h, --help            show this help message and exit
+  -r, --run             run selected history items
+  -e, --edit            edit and then run selected history items
+  -s, --script          script format; no separation lines
+  -o FILE, --output-file FILE
+                        output commands to a script file
+  -t TRANSCRIPT, --transcript TRANSCRIPT
+                        output commands and results to a transcript file
 """
 
 # Output from the shortcuts command with default built-in shortcuts
@@ -47,9 +71,7 @@ expect_colors = True
 if sys.platform.startswith('win'):
     expect_colors = False
 # Output from the show command with default settings
-SHOW_TXT = """abbrev: False
-autorun_on_edit: False
-colors: {}
+SHOW_TXT = """colors: {}
 continuation_prompt: >
 debug: False
 echo: False
@@ -66,8 +88,6 @@ if expect_colors:
 else:
     color_str = 'False'
 SHOW_LONG = """
-abbrev: False             # Accept abbreviated commands
-autorun_on_edit: False    # Automatically run files after editing
 colors: {}             # Colorized output (*nix only)
 continuation_prompt: >    # On 2nd+ line of input
 debug: False              # Show full error stack on error
