@@ -15,16 +15,18 @@ import pytest
 import six
 
 from code import InteractiveConsole
+from optparse import make_option
 
 # Used for sm.input: raw_input() for Python 2 or input() for Python 3
 import six.moves as sm
 
 import cmd2
-from conftest import run_cmd, normalize, BASE_HELP, HELP_HISTORY, SHORTCUTS_TXT, SHOW_TXT, SHOW_LONG, StdOut
+from conftest import run_cmd, normalize, BASE_HELP, BASE_HELP_VERBOSE, \
+    HELP_HISTORY, SHORTCUTS_TXT, SHOW_TXT, SHOW_LONG, StdOut
 
 
 def test_ver():
-    assert cmd2.__version__ == '0.7.9'
+    assert cmd2.__version__ == '0.8.5'
 
 
 def test_empty_statement(base_app):
@@ -37,27 +39,36 @@ def test_base_help(base_app):
     expected = normalize(BASE_HELP)
     assert out == expected
 
+def test_base_help_verbose(base_app):
+    out = run_cmd(base_app, 'help -v')
+    expected = normalize(BASE_HELP_VERBOSE)
+    assert out == expected
+
+    out = run_cmd(base_app, 'help --verbose')
+    assert out == expected
 
 def test_base_help_history(base_app):
     out = run_cmd(base_app, 'help history')
-    expected = normalize(HELP_HISTORY)
-    assert out == expected
+    assert out == normalize(HELP_HISTORY)
 
-def test_base_options_help(base_app, capsys):
-    run_cmd(base_app, 'show -h')
+def test_base_argparse_help(base_app, capsys):
+    # Verify that "set -h" gives the same output as "help set" and that it starts in a way that makes sense
+    run_cmd(base_app, 'set -h')
     out, err = capsys.readouterr()
-    expected = run_cmd(base_app, 'help show')
-    # 'show -h' is the same as 'help show', other than whitespace differences of an extra newline present in 'help show'
-    assert normalize(str(out)) == expected
+    out1 = normalize(str(out))
+
+    out2 = run_cmd(base_app, 'help set')
+
+    assert out1 == out2
+    assert out1[0].startswith('usage: set')
+    assert out1[1] == ''
+    assert out1[2].startswith('Sets a settable parameter')
 
 def test_base_invalid_option(base_app, capsys):
-    run_cmd(base_app, 'show -z')
+    run_cmd(base_app, 'set -z')
     out, err = capsys.readouterr()
-    show_help = run_cmd(base_app, 'help show')
-    expected = ['no such option: -z']
-    expected.extend(show_help)
-    # 'show -h' is the same as 'help show', other than whitespace differences of an extra newline present in 'help show'
-    assert normalize(str(out)) == expected
+    expected = ['usage: set [-h] [-a] [-l] [settable [settable ...]]', 'set: error: unrecognized arguments: -z']
+    assert normalize(str(err)) == expected
 
 def test_base_shortcuts(base_app):
     out = run_cmd(base_app, 'shortcuts')
@@ -68,7 +79,7 @@ def test_base_shortcuts(base_app):
 def test_base_show(base_app):
     # force editor to be 'vim' so test is repeatable across platforms
     base_app.editor = 'vim'
-    out = run_cmd(base_app, 'show')
+    out = run_cmd(base_app, 'set')
     expected = normalize(SHOW_TXT)
     assert out == expected
 
@@ -76,11 +87,30 @@ def test_base_show(base_app):
 def test_base_show_long(base_app):
     # force editor to be 'vim' so test is repeatable across platforms
     base_app.editor = 'vim'
-    out = run_cmd(base_app, 'show -l')
+    out = run_cmd(base_app, 'set -l')
     expected = normalize(SHOW_LONG)
     assert out == expected
 
 
+def test_base_show_readonly(base_app):
+    base_app.editor = 'vim'
+    out = run_cmd(base_app, 'set -a')
+    expected = normalize(SHOW_TXT + '\nRead only settings:' + """
+        Commands may be terminated with: {}
+        Arguments at invocation allowed: {}
+        Output redirection and pipes allowed: {}
+        Parsing of @options commands:
+            Shell lexer mode for command argument splitting: {}
+            Strip Quotes after splitting arguments: {}
+            Argument type: {}
+            
+""".format(base_app.terminators, base_app.allow_cli_args, base_app.allow_redirection,
+           "POSIX" if cmd2.POSIX_SHLEX else "non-POSIX",
+           "True" if cmd2.STRIP_QUOTES_FOR_NON_POSIX and not cmd2.POSIX_SHLEX else "False",
+           "List of argument strings" if cmd2.USE_ARG_LIST else "string of space-separated arguments"))
+    assert out == expected
+
+
 def test_base_set(base_app):
     out = run_cmd(base_app, 'set quiet True')
     expected = normalize("""
@@ -89,7 +119,7 @@ now: True
 """)
     assert out == expected
 
-    out = run_cmd(base_app, 'show quiet')
+    out = run_cmd(base_app, 'set quiet')
     assert out == ['quiet: True']
 
 def test_set_not_supported(base_app, capsys):
@@ -109,7 +139,7 @@ now: True
 """)
     assert out == expected
 
-    out = run_cmd(base_app, 'show quiet')
+    out = run_cmd(base_app, 'set quiet')
     assert out == ['quiet: True']
 
 
@@ -298,25 +328,49 @@ def test_history_with_span_index_error(base_app):
 """)
     assert out == expected
 
+def test_history_output_file(base_app):
+    run_cmd(base_app, 'help')
+    run_cmd(base_app, 'shortcuts')
+    run_cmd(base_app, 'help history')
 
-def test_base_cmdenvironment(base_app):
-    out = run_cmd(base_app, 'cmdenvironment')
-    expected = normalize("""
+    fd, fname = tempfile.mkstemp(prefix='', suffix='.txt')
+    os.close(fd)
+    run_cmd(base_app, 'history -o "{}"'.format(fname))
+    expected = normalize('\n'.join(['help', 'shortcuts', 'help history']))
+    with open(fname) as f:
+        content = normalize(f.read())
+    assert content == expected
 
-        Commands are case-sensitive: {}
-        Commands may be terminated with: {}
-        Arguments at invocation allowed: {}
-        Output redirection and pipes allowed: {}
-        Parsing of @options commands:
-            Shell lexer mode for command argument splitting: {}
-            Strip Quotes after splitting arguments: {}
-            Argument type: {}
-            
-""".format(not base_app.case_insensitive, base_app.terminators, base_app.allow_cli_args, base_app.allow_redirection,
-           "POSIX" if cmd2.POSIX_SHLEX else "non-POSIX",
-           "True" if cmd2.STRIP_QUOTES_FOR_NON_POSIX and not cmd2.POSIX_SHLEX else "False",
-           "List of argument strings" if cmd2.USE_ARG_LIST else "string of space-separated arguments"))
-    assert out == expected
+def test_history_edit(base_app, monkeypatch):
+    # Set a fake editor just to make sure we have one.  We aren't really
+    # going to call it due to the mock
+    base_app.editor = 'fooedit'
+
+    # Mock out the os.system call so we don't actually open an editor
+    m = mock.MagicMock(name='system')
+    monkeypatch.setattr("os.system", m)
+
+    # Run help command just so we have a command in history
+    run_cmd(base_app, 'help')
+    run_cmd(base_app, 'history -e 1')
+
+    # We have an editor, so should expect a system call
+    m.assert_called_once()
+
+def test_history_run_all_commands(base_app):
+    # make sure we refuse to run all commands as a default
+    run_cmd(base_app, 'shortcuts')
+    out = run_cmd(base_app, 'history -r')
+    # this should generate an error, but we don't currently have a way to
+    # capture stderr in these tests. So we assume that if we got nothing on
+    # standard out, that the error occured because if the commaned executed
+    # then we should have a list of shortcuts in our output
+    assert out == []
+
+def test_history_run_one_command(base_app):
+    expected = run_cmd(base_app, 'help')
+    output = run_cmd(base_app, 'history -r 1')
+    assert output == expected
 
 def test_base_load(base_app, request):
     test_dir = os.path.dirname(request.module.__file__)
@@ -422,12 +476,10 @@ def test_load_nested_loads(base_app, request):
     expected = """
 %s
 _relative_load precmds.txt
-set abbrev on
 set colors on
 help
 shortcuts
 _relative_load postcmds.txt
-set abbrev off
 set colors off""" % initial_load
     assert run_cmd(base_app, 'history -s') == normalize(expected)
 
@@ -446,12 +498,10 @@ def test_base_runcmds_plus_hooks(base_app, request):
                                  'load ' + postfilepath])
     expected = """
 load %s
-set abbrev on
 set colors on
 help
 shortcuts
 load %s
-set abbrev off
 set colors off""" % (prefilepath, postfilepath)
     assert run_cmd(base_app, 'history -s') == normalize(expected)
 
@@ -480,88 +530,6 @@ def test_relative_load_requires_an_argument(base_app, capsys):
     assert base_app.cmdqueue == []
 
 
-def test_base_save(base_app):
-    # TODO: Use a temporary directory for the file
-    filename = 'deleteme.txt'
-    base_app.feedback_to_output = True
-    run_cmd(base_app, 'help')
-    run_cmd(base_app, 'help save')
-
-    # Test the * form of save which saves all commands from history
-    out = run_cmd(base_app, 'save * {}'.format(filename))
-    assert out == normalize('Saved to {}\n'.format(filename))
-    expected = normalize("""
-help
-
-help save
-
-save * deleteme.txt
-""")
-    with open(filename) as f:
-        content = normalize(f.read())
-    assert content == expected
-
-    # Test the N form of save which saves a numbered command from history
-    out = run_cmd(base_app, 'save 1 {}'.format(filename))
-    assert out == normalize('Saved to {}\n'.format(filename))
-    expected = normalize('help')
-    with open(filename) as f:
-        content = normalize(f.read())
-    assert content == expected
-
-    # Test the blank form of save which saves the most recent command from history
-    out = run_cmd(base_app, 'save {}'.format(filename))
-    assert out == normalize('Saved to {}\n'.format(filename))
-    expected = normalize('save 1 {}'.format(filename))
-    with open(filename) as f:
-        content = normalize(f.read())
-    assert content == expected
-
-    # Delete file that was created
-    os.remove(filename)
-
-def test_save_parse_error(base_app, capsys):
-    invalid_file = '~!@'
-    run_cmd(base_app, 'save {}'.format(invalid_file))
-    out, err = capsys.readouterr()
-    assert out == ''
-    assert err.startswith('ERROR: Could not understand save target {}\n'.format(invalid_file))
-
-def test_save_tempfile(base_app):
-    # Just run help to make sure there is something in the history
-    base_app.feedback_to_output = True
-    run_cmd(base_app, 'help')
-    out = run_cmd(base_app, 'save *')
-    output = out[0]
-    assert output.startswith('Saved to ')
-
-    # Delete the tempfile which was created
-    temp_file = output.split('Saved to ')[1].strip()
-    os.remove(temp_file)
-
-def test_save_invalid_history_index(base_app, capsys):
-    run_cmd(base_app, 'save 5')
-    out, err = capsys.readouterr()
-    assert out == ''
-    assert err.startswith("EXCEPTION of type 'IndexError' occurred with message: 'list index out of range'\n")
-
-def test_save_empty_history_and_index(base_app, capsys):
-    run_cmd(base_app, 'save')
-    out, err = capsys.readouterr()
-    assert out == ''
-    assert err.startswith("ERROR: History is empty, nothing to save.\n")
-
-def test_save_invalid_path(base_app, capsys):
-    # Just run help to make sure there is something in the history
-    run_cmd(base_app, 'help')
-
-    invalid_path = '/no_such_path/foobar.txt'
-    run_cmd(base_app, 'save {}'.format(invalid_path))
-    out, err = capsys.readouterr()
-    assert out == ''
-    assert err.startswith("ERROR: Saving '{}' - ".format(invalid_path))
-
-
 def test_output_redirection(base_app):
     fd, filename = tempfile.mkstemp(prefix='cmd2_test', suffix='.txt')
     os.close(fd)
@@ -645,20 +613,13 @@ def test_input_redirection(base_app, request):
 
     # Verify that redirecting input ffom a file works
     out = run_cmd(base_app, 'help < {}'.format(filename))
-    expected = normalize(HELP_HISTORY)
-    assert out == expected
+    assert out == normalize(HELP_HISTORY)
 
 
 def test_pipe_to_shell(base_app, capsys):
     if sys.platform == "win32":
         # Windows
         command = 'help | sort'
-        # Get help menu and pipe it's output to the sort shell command
-        # expected = ['', '', '_relative_load  edit  history  py        quit  save  shell      show',
-        #             '========================================',
-        #             'cmdenvironment  help  load     pyscript  run   set   shortcuts',
-        #             'Documented commands (type help <topic>):']
-        # assert out == expected
     else:
         # Mac and Linux
         # Get help on help and pipe it's output to the input of the word count shell command
@@ -820,84 +781,11 @@ def test_edit_blank(base_app, monkeypatch):
     m = mock.MagicMock(name='system')
     monkeypatch.setattr("os.system", m)
 
-    # Run help command just so we have a command in history
-    run_cmd(base_app, 'help')
-
     run_cmd(base_app, 'edit')
 
     # We have an editor, so should expect a system call
     m.assert_called_once()
 
-def test_edit_empty_history(base_app, capsys):
-    run_cmd(base_app, 'edit')
-    out, err = capsys.readouterr()
-    assert out == ''
-    assert err == 'ERROR: edit must be called with argument if history is empty\n'
-
-def test_edit_valid_positive_number(base_app, monkeypatch):
-    # Set a fake editor just to make sure we have one.  We aren't really going to call it due to the mock
-    base_app.editor = 'fooedit'
-
-    # Mock out the os.system call so we don't actually open an editor
-    m = mock.MagicMock(name='system')
-    monkeypatch.setattr("os.system", m)
-
-    # Run help command just so we have a command in history
-    run_cmd(base_app, 'help')
-
-    run_cmd(base_app, 'edit 1')
-
-    # We have an editor, so should expect a system call
-    m.assert_called_once()
-
-def test_edit_valid_negative_number(base_app, monkeypatch):
-    # Set a fake editor just to make sure we have one.  We aren't really going to call it due to the mock
-    base_app.editor = 'fooedit'
-
-    # Mock out the os.system call so we don't actually open an editor
-    m = mock.MagicMock(name='system')
-    monkeypatch.setattr("os.system", m)
-
-    # Run help command just so we have a command in history
-    run_cmd(base_app, 'help')
-
-    run_cmd(base_app, 'edit "-1"')
-
-    # We have an editor, so should expect a system call
-    m.assert_called_once()
-
-def test_edit_invalid_positive_number(base_app, monkeypatch):
-    # Set a fake editor just to make sure we have one.  We aren't really going to call it due to the mock
-    base_app.editor = 'fooedit'
-
-    # Mock out the os.system call so we don't actually open an editor
-    m = mock.MagicMock(name='system')
-    monkeypatch.setattr("os.system", m)
-
-    # Run help command just so we have a command in history
-    run_cmd(base_app, 'help')
-
-    run_cmd(base_app, 'edit 23')
-
-    # History index is invalid, so should expect a system call
-    m.assert_not_called()
-
-def test_edit_invalid_negative_number(base_app, monkeypatch):
-    # Set a fake editor just to make sure we have one.  We aren't really going to call it due to the mock
-    base_app.editor = 'fooedit'
-
-    # Mock out the os.system call so we don't actually open an editor
-    m = mock.MagicMock(name='system')
-    monkeypatch.setattr("os.system", m)
-
-    # Run help command just so we have a command in history
-    run_cmd(base_app, 'help')
-
-    run_cmd(base_app, 'edit "-23"')
-
-    # History index is invalid, so should expect a system call
-    m.assert_not_called()
-
 
 def test_base_py_interactive(base_app):
     # Mock out the InteractiveConsole.interact() call so we don't actually wait for a user's response on stdin
@@ -910,6 +798,30 @@ def test_base_py_interactive(base_app):
     m.assert_called_once()
 
 
+def test_exclude_from_history(base_app, monkeypatch):
+    # Mock out the os.system call so we don't actually open an editor
+    m = mock.MagicMock(name='system')
+    monkeypatch.setattr("os.system", m)
+
+    # Run edit command
+    run_cmd(base_app, 'edit')
+
+    # Run history command
+    run_cmd(base_app, 'history')
+
+    # Verify that the history is empty
+    out = run_cmd(base_app, 'history')
+    assert out == []
+
+    # Now run a command which isn't excluded from the history
+    run_cmd(base_app, 'help')
+    # And verify we have a history now ...
+    out = run_cmd(base_app, 'history')
+    expected = normalize("""-------------------------[1]
+help""")
+    assert out == expected
+
+
 def test_base_cmdloop_with_queue():
     # Create a cmd2.Cmd() instance and make sure basic settings are like we want for test
     app = cmd2.Cmd()
@@ -996,6 +908,49 @@ def test_precmd_hook_failure(hook_failure):
     assert out == True
 
 
+class SayApp(cmd2.Cmd):
+    def __init__(self, *args, **kwargs):
+        # Need to use this older form of invoking super class constructor to support Python 2.x and Python 3.x
+        cmd2.Cmd.__init__(self, *args, **kwargs)
+
+    def do_say(self, arg):
+        self.poutput(arg)
+
+@pytest.fixture
+def say_app():
+    app = SayApp()
+    app.stdout = StdOut()
+    return app
+
+def test_interrupt_quit(say_app):
+    say_app.quit_on_sigint = True
+
+    # Mock out the input call so we don't actually wait for a user's response on stdin
+    m = mock.MagicMock(name='input')
+    m.side_effect = ['say hello', KeyboardInterrupt(), 'say goodbye', 'eof']
+    sm.input = m
+
+    say_app.cmdloop()
+
+    # And verify the expected output to stdout
+    out = say_app.stdout.buffer
+    assert out == 'hello\n'
+
+def test_interrupt_noquit(say_app):
+    say_app.quit_on_sigint = False
+
+    # Mock out the input call so we don't actually wait for a user's response on stdin
+    m = mock.MagicMock(name='input')
+    m.side_effect = ['say hello', KeyboardInterrupt(), 'say goodbye', 'eof']
+    sm.input = m
+
+    say_app.cmdloop()
+
+    # And verify the expected output to stdout
+    out = say_app.stdout.buffer
+    assert out == 'hello\n^C\ngoodbye\n'
+
+
 class ShellApp(cmd2.Cmd):
     def __init__(self, *args, **kwargs):
         # Need to use this older form of invoking super class constructor to support Python 2.x and Python 3.x
@@ -1099,8 +1054,8 @@ def test_custom_help_menu(help_app):
     expected = normalize("""
 Documented commands (type help <topic>):
 ========================================
-_relative_load  edit  history  py        quit  save  shell      show
-cmdenvironment  help  load     pyscript  run   set   shortcuts  squat
+alias  help     load  pyscript  set    shortcuts  unalias
+edit   history  py    quit      shell  squat
 
 Undocumented commands:
 ======================
@@ -1119,6 +1074,96 @@ def test_help_overridden_method(help_app):
     assert out == expected
 
 
+class HelpCategoriesApp(cmd2.Cmd):
+    """Class for testing custom help_* methods which override docstring help."""
+    def __init__(self, *args, **kwargs):
+        # Need to use this older form of invoking super class constructor to support Python 2.x and Python 3.x
+        cmd2.Cmd.__init__(self, *args, **kwargs)
+
+    @cmd2.with_category('Some Category')
+    def do_diddly(self, arg):
+        """This command does diddly"""
+        pass
+
+    def do_squat(self, arg):
+        """This docstring help will never be shown because the help_squat method overrides it."""
+        pass
+
+    def help_squat(self):
+        self.stdout.write('This command does diddly squat...\n')
+
+    def do_edit(self, arg):
+        """This overrides the edit command and does nothing."""
+        pass
+
+    cmd2.categorize((do_squat, do_edit), 'Custom Category')
+
+    # This command will be in the "undocumented" section of the help menu
+    def do_undoc(self, arg):
+        pass
+
+@pytest.fixture
+def helpcat_app():
+    app = HelpCategoriesApp()
+    app.stdout = StdOut()
+    return app
+
+def test_help_cat_base(helpcat_app):
+    out = run_cmd(helpcat_app, 'help')
+    expected = normalize("""Documented commands (type help <topic>):
+
+Custom Category
+===============
+edit  squat
+
+Some Category
+=============
+diddly
+
+Other
+=====
+alias  help  history  load  py  pyscript  quit  set  shell  shortcuts  unalias
+
+Undocumented commands:
+======================
+undoc
+""")
+    assert out == expected
+
+def test_help_cat_verbose(helpcat_app):
+    out = run_cmd(helpcat_app, 'help --verbose')
+    expected = normalize("""Documented commands (type help <topic>):
+
+Custom Category
+================================================================================
+edit                This overrides the edit command and does nothing.
+squat               This command does diddly squat...
+
+Some Category
+================================================================================
+diddly              This command does diddly
+
+Other
+================================================================================
+alias               Define or display aliases
+help                List available commands with "help" or detailed help with "help cmd".
+history             View, run, edit, and save previously entered commands.
+load                Runs commands in script file that is encoded as either ASCII or UTF-8 text.
+py                  Invoke python command, shell, or script
+pyscript            Runs a python script file inside the console
+quit                Exits this application.
+set                 Sets a settable parameter or shows current settings of parameters.
+shell               Execute a command as if at the OS prompt.
+shortcuts           Lists shortcuts (aliases) available.
+unalias             Unsets aliases
+
+Undocumented commands:
+======================
+undoc
+""")
+    assert out == expected
+
+
 class SelectApp(cmd2.Cmd):
     def do_eat(self, arg):
         """Eat something, with a selection of sauces to choose from."""
@@ -1274,7 +1319,7 @@ arg 2: 'bar'
 
 
 class OptionApp(cmd2.Cmd):
-    @cmd2.options([cmd2.make_option('-s', '--shout', action="store_true", help="N00B EMULATION MODE")])
+    @cmd2.options([make_option('-s', '--shout', action="store_true", help="N00B EMULATION MODE")])
     def do_greet(self, arg, opts=None):
         arg = ''.join(arg)
         if opts.shout:
@@ -1317,7 +1362,7 @@ class MultilineApp(cmd2.Cmd):
         # Need to use this older form of invoking super class constructor to support Python 2.x and Python 3.x
         cmd2.Cmd.__init__(self, *args, **kwargs)
 
-    @cmd2.options([cmd2.make_option('-s', '--shout', action="store_true", help="N00B EMULATION MODE")])
+    @cmd2.options([make_option('-s', '--shout', action="store_true", help="N00B EMULATION MODE")])
     def do_orate(self, arg, opts=None):
         arg = ''.join(arg)
         if opts.shout:
@@ -1361,20 +1406,6 @@ def test_clipboard_failure(capsys):
     assert 'Cannot redirect to paste buffer; install ``xclip`` and re-run to enable' in err
 
 
-def test_run_command_with_empty_arg(base_app):
-    command = 'help'
-    base_app.feedback_to_output = True
-    run_cmd(base_app, command)
-    out = run_cmd(base_app, 'run')
-    expected = normalize('{}\n\n'.format(command) + BASE_HELP)
-    assert out == expected
-
-def test_run_command_with_empty_history(base_app):
-    base_app.feedback_to_output = True
-    out = run_cmd(base_app, 'run')
-    assert out == []
-
-
 class CmdResultApp(cmd2.Cmd):
     def __init__(self, *args, **kwargs):
         # Need to use this older form of invoking super class constructor to support Python 2.x and Python 3.x
@@ -1404,49 +1435,6 @@ def test_cmdresult(cmdresult_app):
     assert cmdresult_app._last_result == cmd2.CmdResult('', arg)
 
 
-@pytest.fixture
-def abbrev_app():
-    app = cmd2.Cmd()
-    app.abbrev = True
-    app.stdout = StdOut()
-    return app
-
-def test_exclude_from_history(abbrev_app, monkeypatch):
-    # Run all variants of run
-    run_cmd(abbrev_app, 'run')
-    run_cmd(abbrev_app, 'ru')
-    run_cmd(abbrev_app, 'r')
-
-    # Mock out the os.system call so we don't actually open an editor
-    m = mock.MagicMock(name='system')
-    monkeypatch.setattr("os.system", m)
-
-    # Run all variants of edit
-    run_cmd(abbrev_app, 'edit')
-    run_cmd(abbrev_app, 'edi')
-    run_cmd(abbrev_app, 'ed')
-
-    # Run all variants of history
-    run_cmd(abbrev_app, 'history')
-    run_cmd(abbrev_app, 'histor')
-    run_cmd(abbrev_app, 'histo')
-    run_cmd(abbrev_app, 'hist')
-    run_cmd(abbrev_app, 'his')
-    run_cmd(abbrev_app, 'hi')
-
-    # Verify that the history is empty
-    out = run_cmd(abbrev_app, 'history')
-    assert out == []
-
-    # Now run a command which isn't excluded from the history
-    run_cmd(abbrev_app, 'help')
-    # And verify we have a history now ...
-    out = run_cmd(abbrev_app, 'history')
-    expected = normalize("""-------------------------[1]
-help""")
-    assert out == expected
-
-
 def test_is_text_file_bad_input(base_app):
     # Test with a non-existent file
     file_is_valid = base_app.is_text_file('does_not_exist.txt')
@@ -1490,7 +1478,7 @@ def test_echo(capsys):
     # Check the output
     assert app.cmdqueue == []
     assert app._current_script_dir is None
-    assert out.startswith('{}{}\n'.format(app.prompt, command) + 'history [arg]: lists past commands issued')
+    assert out.startswith('{}{}\n'.format(app.prompt, command) + HELP_HISTORY.split()[0])
 
 def test_pseudo_raw_input_tty_rawinput_true():
     # use context managers so original functions get put back when we are done
@@ -1550,7 +1538,7 @@ def test_pseudo_raw_input_piped_rawinput_true_echo_true(capsys):
     app, out = piped_rawinput_true(capsys, True, command)
     out = out.splitlines()
     assert out[0] == '{}{}'.format(app.prompt, command)
-    assert out[1] == 'abbrev: False'
+    assert out[1].startswith('colors:')
 
 # using the decorator puts the original function at six.moves.input
 # back when this method returns
@@ -1560,7 +1548,7 @@ def test_pseudo_raw_input_piped_rawinput_true_echo_false(capsys):
     command = 'set'
     app, out = piped_rawinput_true(capsys, False, command)
     firstline = out.splitlines()[0]
-    assert firstline == 'abbrev: False'
+    assert firstline.startswith('colors:')
     assert not '{}{}'.format(app.prompt, command) in out
 
 # the next helper function and two tests check for piped
@@ -1571,7 +1559,6 @@ def piped_rawinput_false(capsys, echo, command):
     app = cmd2.Cmd(stdin=fakein)
     app.use_rawinput = False
     app.echo = echo
-    app.abbrev = False
     app._cmdloop()
     out, err = capsys.readouterr()
     return (app, out)
@@ -1581,13 +1568,13 @@ def test_pseudo_raw_input_piped_rawinput_false_echo_true(capsys):
     app, out = piped_rawinput_false(capsys, True, command)
     out = out.splitlines()
     assert out[0] == '{}{}'.format(app.prompt, command)
-    assert out[1] == 'abbrev: False'
+    assert out[1].startswith('colors:')
 
 def test_pseudo_raw_input_piped_rawinput_false_echo_false(capsys):
     command = 'set'
     app, out = piped_rawinput_false(capsys, False, command)
     firstline = out.splitlines()[0]
-    assert firstline == 'abbrev: False'
+    assert firstline.startswith('colors:')
     assert not '{}{}'.format(app.prompt, command) in out
 
 #
@@ -1655,3 +1642,51 @@ def test_poutput_none(base_app):
     out = base_app.stdout.buffer
     expected = ''
     assert out == expected
+
+
+def test_alias(base_app, capsys):
+    # Create the alias
+    out = run_cmd(base_app, 'alias fake pyscript')
+    assert out == normalize("Alias 'fake' created")
+
+    # Use the alias
+    run_cmd(base_app, 'fake')
+    out, err = capsys.readouterr()
+    assert "pyscript command requires at least 1 argument" in err
+
+    # See a list of aliases
+    out = run_cmd(base_app, 'alias')
+    assert out == normalize('alias fake pyscript')
+
+    # Lookup the new alias
+    out = run_cmd(base_app, 'alias fake')
+    assert out == normalize('alias fake pyscript')
+
+def test_alias_lookup_invalid_alias(base_app, capsys):
+    # Lookup invalid alias
+    out = run_cmd(base_app, 'alias invalid')
+    out, err = capsys.readouterr()
+    assert "not found" in err
+
+def test_alias_with_invalid_name(base_app, capsys):
+    run_cmd(base_app, 'alias @ help')
+    out, err = capsys.readouterr()
+    assert "can only contain the following characters" in err
+
+
+def test_unalias(base_app):
+    # Create an alias
+    run_cmd(base_app, 'alias fake pyscript')
+
+    # Remove the alias
+    out = run_cmd(base_app, 'unalias fake')
+    assert out == normalize("Alias 'fake' cleared")
+
+def test_unalias_all(base_app):
+    out = run_cmd(base_app, 'unalias -a')
+    assert out == normalize("All aliases cleared")
+
+def test_unalias_non_existing(base_app, capsys):
+    run_cmd(base_app, 'unalias fake')
+    out, err = capsys.readouterr()
+    assert "does not exist" in err
