@@ -7,18 +7,17 @@ Released under MIT license, see LICENSE file
 """
 import os
 import sys
+import re
 import random
 
 import mock
 import pytest
 import six
 
-# Used for sm.input: raw_input() for Python 2 or input() for Python 3
-import six.moves as sm
-
-from cmd2 import (Cmd, make_option, options, Cmd2TestCase, set_use_arg_list,
+from cmd2 import (Cmd, options, Cmd2TestCase, set_use_arg_list,
                   set_posix_shlex, set_strip_quotes)
 from conftest import run_cmd, StdOut, normalize
+from optparse import make_option
 
 
 class CmdLineApp(Cmd):
@@ -26,9 +25,8 @@ class CmdLineApp(Cmd):
     MUMBLES = ['like', '...', 'um', 'er', 'hmmm', 'ahh']
     MUMBLE_FIRST = ['so', 'like', 'well']
     MUMBLE_LAST = ['right?']
-    
+
     def __init__(self, *args, **kwargs):
-        self.abbrev = True
         self.multilineCommands = ['orate']
         self.maxrepeats = 3
         self.redirector = '->'
@@ -131,9 +129,8 @@ def test_base_with_transcript(_cmdline_app):
 
 Documented commands (type help <topic>):
 ========================================
-_relative_load  help     mumble  pyscript  save  shell      speak
-cmdenvironment  history  orate   quit      say   shortcuts
-edit            load     py      run       set   show
+alias  help     load    orate  pyscript  say  shell      speak  
+edit   history  mumble  py     quit      set  shortcuts  unalias
 
 (Cmd) help say
 Repeats what you tell me to.
@@ -161,7 +158,7 @@ OODNIGHT, GRACIEGAY
 OODNIGHT, GRACIEGAY
 OODNIGHT, GRACIEGAY
 OODNIGHT, GRACIEGAY
-(Cmd) hi
+(Cmd) history
 -------------------------[1]
 help
 -------------------------[2]
@@ -174,7 +171,7 @@ say -ps --repeat=5 goodnight, Gracie
 set maxrepeats 5
 -------------------------[6]
 say -ps --repeat=5 goodnight, Gracie
-(Cmd) run 4
+(Cmd) history -r 4
 OODNIGHT, GRACIEGAY
 OODNIGHT, GRACIEGAY
 OODNIGHT, GRACIEGAY
@@ -309,25 +306,29 @@ def test_transcript(request, capsys, filename, feedback_to_output):
 
 
 @pytest.mark.parametrize('expected, transformed', [
-    ( 'text with no slashes', 'text\ with\ no\ slashes' ),
-    # stuff with just one slash
-    ( 'use 2/3 cup', 'use\ 2\/3\ cup' ),
-    ( '/tmp is nice', '\/tmp\ is\ nice'),
-    ( 'slash at end/', 'slash\ at\ end\/'),
+    # strings with zero or one slash or with escaped slashes means no regular
+    # expression present, so the result should just be what re.escape returns.
+    # we don't use static strings in these tests because re.escape behaves
+    # differently in python 3.7 than in prior versions
+    ( 'text with no slashes', re.escape('text with no slashes') ),
+    ( 'specials .*', re.escape('specials .*') ),
+    ( 'use 2/3 cup', re.escape('use 2/3 cup') ),
+    ( '/tmp is nice', re.escape('/tmp is nice') ),
+    ( 'slash at end/', re.escape('slash at end/') ),
+    # escaped slashes
+    ( 'not this slash\/ or this one\/', re.escape('not this slash/ or this one/' ) ),
     # regexes
-    ( 'specials .*', 'specials\ \.\*' ),
     ( '/.*/', '.*' ),
-    ( 'specials ^ and + /[0-9]+/', 'specials\ \^\ and\ \+\ [0-9]+' ),
-    ( '/a{6}/ but not \/a{6} with /.*?/ more', 'a{6}\ but\ not\ \/a\{6\}\ with\ .*?\ more' ),
-    ( 'not this slash\/ or this one\/', 'not\ this\ slash\\/\ or\ this\ one\\/' ),
-    ( 'not \/, use /\|?/, not \/', 'not\ \\/\,\ use\ \|?\,\ not\ \\/' ),
+    ( 'specials ^ and + /[0-9]+/', re.escape('specials ^ and + ') + '[0-9]+' ),
+    ( '/a{6}/ but not \/a{6} with /.*?/ more', 'a{6}' + re.escape(' but not /a{6} with ') + '.*?' + re.escape(' more') ),
+    ( 'not \/, use /\|?/, not \/', re.escape('not /, use ') + '\|?' + re.escape(', not /') ),
     # inception: slashes in our regex. backslashed on input, bare on output
-    ( 'not \/, use /\/?/, not \/', 'not\ \\/\,\ use\ /?\,\ not\ \\/' ),
-    ( 'the /\/?/ more /.*/ stuff', 'the\ /?\ more\ .*\ stuff' ),
+    ( 'not \/, use /\/?/, not \/', re.escape('not /, use ') + '/?' + re.escape(', not /') ),
+    ( 'lots /\/?/ more /.*/ stuff', re.escape('lots ') + '/?' + re.escape(' more ') + '.*' + re.escape(' stuff') ),
     ])
 def test_parse_transcript_expected(expected, transformed):
     app = CmdLineApp()
-    
+
     class TestMyAppCase(Cmd2TestCase):
         cmdapp = app
 
